# Parser en Python

## Description
Ce repo contient le code d'un module python permettant de parser du code source pour en extraire des indicateurs.

## Installation
Depuis Git bash : 

1. Cloner le projet (master)
2. cd parser
3. pip install -r requirements.txt
4. py.test

## Contribution
1. Cloner le projet
2. Créer une nouvelle branche
3. Check out la branche
4. Commit et push du code
5. Créer un PR et alerter l'équipe

## Convention
* Le code et les commentaires seront de préférence en Français
* On utilisera Python 3.7
* Le linter sera PyLint

## Documentation
[Schema des classes](https://drive.google.com/drive/folders/1uquCE7LE1dYdJEXwpesMFMWH9KIWeSem?usp=sharing)